public inbox for gentoo-catalyst@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-catalyst] [PATCH] Fix mis-spelling of 'received' in chroot-functions.sh
@ 2018-09-09 17:35 M. J. Everitt
  0 siblings, 0 replies; only message in thread
From: M. J. Everitt @ 2018-09-09 17:35 UTC (permalink / raw
  To: gentoo-catalyst


[-- Attachment #1.1: Type: text/plain, Size: 1870 bytes --]

From 58119dd43d6c1f28a6c0dd935a262d9da8e941b4 Mon Sep 17 00:00:00 2001
From: Michael Everitt <m.j.everitt@iee.org>
Date: Sun, 9 Sep 2018 18:17:27 +0100
Subject: [PATCH] Fix mis-spelling of 'received' in chroot-functions.sh

---
 targets/support/chroot-functions.sh | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/targets/support/chroot-functions.sh
b/targets/support/chroot-functions.sh
index 84d90fe..ceef21c 100755
--- a/targets/support/chroot-functions.sh
+++ b/targets/support/chroot-functions.sh
@@ -3,19 +3,19 @@
 # Set the profile
 eselect profile set ${clst_target_profile}
 -# Trap these signals and kill ourselves if recieved
 # Force ourselves to die if any of these signals are recieved
 # most likely our controlling terminal is gone
-trap "echo SIGTERM signal recieved killing $0 with pid $$;kill -9 $$"
SIGTERM
-trap "echo SIGHUP signal recieved killing $0 with pid $$;kill -9 $$" SIGHUP
-trap "echo SIGKILL signal recieved killing $0 with pid $$;kill -9 $$"
SIGKILL
+trap "echo SIGTERM signal received killing $0 with pid $$;kill -9 $$"
SIGTERM
+trap "echo SIGHUP signal received killing $0 with pid $$;kill -9 $$" SIGHUP
+trap "echo SIGKILL signal received killing $0 with pid $$;kill -9 $$"
SIGKILL
  #SIGINT interrupt character (usually Ctrl-C)
 #	* example: high-level sequence of events
 #	* my process (call it "P") is running
 #	* user types ctrl-c
 #	* kernel recognizes this and generates SIGINT signal
-trap "echo SIGINT signal recieved killing $0 with pid $$;kill -9 $$" SIGINT
+trap "echo SIGINT signal received killing $0 with pid $$;kill -9 $$" SIGINT
  # test if CHOST was set on the python side
 if [[ -z "${clst_CHOST}" ]] ; then
@@ -3,19 +3,19 @@
 eselect profile set ${clst_target_profile}
 -# Trap these signals and kill ourselves if recieved
-# Force ourselves to die if any of these signals are recieved
+# Trap these signals and kill ourselves if received
+# Force ourselves to die if any of these signals are received
 # most likely our controlling terminal is gone
-- 
2.13.6



[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 819 bytes --]

^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2018-09-09 17:35 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2018-09-09 17:35 [gentoo-catalyst] [PATCH] Fix mis-spelling of 'received' in chroot-functions.sh M. J. Everitt

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox